==> nextcloud-app-spreed-1%3A8.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/mn.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Зочин",
    "Everyone" : "Бүх хэрэглэгчид",
    "Save changes" : "Өөрчлөлтийг хадгалах",
    "Saved!" : "Хадгалагдлаа!",
    "None" : "юу ч үгүй",
    "User" : "Хэрэглэгч",
    "Disabled" : "идэвхигүй",
    "Users" : "хэрэглэгч",
    "Name" : "Нэр",
    "Saved" : "Хадгалах",
    "Favorite" : "Дуртай",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Contacts" : "Харилцагчид",
    "Loading" : "Loading",
    "Groups" : "бүлэгүүд",
    "Circles" : "Тойрог",
    "Error" : "Алдаа",
    "Password protect" : "Нууц үгээр хамгаалах",
    "Back" : "буцах",
    "Close" : "Хаах",
    "Reply" : "хариулт",
    "Today" : "өнөөдөр",
    "Yesterday" : "өчигдөр",
    "No results" : "Үр дүн байхгүй",
    "Settings" : "Тохиргоо",
    "Edit" : "засварлах",
    "Dismiss" : "Арилгах",
    "Share link" : "Холбоос хуваалцах",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Password" : "Нууц үг",
    "Copy" : "Хуулах",
    "Copied!" : "Хуулсан!",
    "Not supported!" : "Дэмжигдэхгүй",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "Cancel" : "болиулах",
    "Submit" : "мэдэгдэх",
    "Change password" : "Нууц үг солих",
    "Rename" : "Нэрлэнэ үү",
    "Send" : "илгээх",
    "Share" : "Түгээх",
    "Error while sharing" : "Түгээхэд алдаа гарлаа"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A9.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/mn.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Зочин",
    "Everyone" : "Бүх хэрэглэгчид",
    "Save changes" : "Өөрчлөлтийг хадгалах",
    "Saved!" : "Хадгалагдлаа!",
    "None" : "юу ч үгүй",
    "User" : "Хэрэглэгч",
    "Disabled" : "идэвхигүй",
    "Users" : "хэрэглэгч",
    "Name" : "Нэр",
    "Saved" : "Хадгалах",
    "Favorite" : "Дуртай",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "бүлэгүүд",
    "Circles" : "Тойрог",
    "Error" : "Алдаа",
    "Password protect" : "Нууц үгээр хамгаалах",
    "Back" : "буцах",
    "Close" : "Хаах",
    "Reply" : "хариулт",
    "Today" : "өнөөдөр",
    "Yesterday" : "өчигдөр",
    "No results" : "Үр дүн байхгүй",
    "Add users or groups" : "Add users or groups",
    "Settings" : "Тохиргоо",
    "Edit" : "засварлах",
    "Dismiss" : "Арилгах",
    "Share link" : "Холбоос хуваалцах",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Password" : "Нууц үг",
    "Copy" : "Хуулах",
    "Copied!" : "Хуулсан!",
    "Not supported!" : "Дэмжигдэхгүй",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "Cancel" : "болиулах",
    "Submit" : "мэдэгдэх",
    "Change password" : "Нууц үг солих",
    "Rename" : "Нэрлэнэ үү",
    "Send" : "илгээх",
    "Share" : "Түгээх",
    "Error while sharing" : "Түгээхэд алдаа гарлаа",
    "Contacts" : "Харилцагчид"
},
"nplurals=2; plural=(n != 1);");
